@@ -1,8 +1,8 @@
-'use strict';
+import process from 'process'; // eslint-disable-line node/prefer-global/process
 
-module.exports = (flag, argv = process.argv) => {
+export default function hasFlag(flag, argv = process.argv) {
 	const prefix = flag.startsWith('-') ? '' : (flag.length === 1 ? '-' : '--');
 	const position = argv.indexOf(prefix + flag);
 	const terminatorPosition = argv.indexOf('--');
 	return position !== -1 && (terminatorPosition === -1 || position < terminatorPosition);
-};
+}
