@@ -1,5 +1,5 @@
 import {expectType} from 'tsd';
-import hasFlag = require('.');
+import hasFlag from './index.js';
 
 expectType<boolean>(hasFlag('unicorn'));
 expectType<boolean>(hasFlag('unicorn', ['--foo']));
